##############################################################################
#
# Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#                    Fabien Pinckaers <fp@tiny.Be>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from osv import osv, fields

class stock_move(osv.osv):
	_inherit = 'stock.move'
	_columns = {
		'sale_line_id': fields.many2one('sale.order.line', 'Sale Order Line', ondelete='set null', select=True),
	}
	_defaults = {
		'sale_line_id': lambda *a:False
	}
stock_move()

class stock_picking(osv.osv):
	_inherit = 'stock.picking'
	_columns = {
		'sale_id': fields.many2one('sale.order', 'Sale Order', ondelete='set null', select=True),
	}
	_defaults = {
		'sale_id': lambda *a: False
	}
stock_picking()


